@@ -1,4 +1,4 @@
-// $Id: syscall_getvhiname.c,v 1.1 2004/02/02 18:32:53 ensc Exp $    --*- c -*--
+// $Id: syscall_getvhiname.c,v 1.2 2005/10/29 10:31:42 ensc Exp $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -21,7 +21,7 @@
 #endif
 
 #include "vserver.h"
-#include "linuxvirtual.h"
+#include "virtual.h"
 
 #if defined(VC_ENABLE_API_OLDUTS) && defined(VC_ENABLE_API_V13)
 #  define VC_MULTIVERSION_SYSCALL	1
