@@ -1,4 +1,4 @@
-// $Id: compat-pivot_root.h,v 1.2 2003/12/30 19:15:06 ensc Exp $    --*- c++ -*--
+// $Id: compat-pivot_root.h,v 1.3 2005/05/02 21:44:06 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -19,11 +19,11 @@
 #ifndef H_UTIL_VSERVER_SRC_COMPAT_PIVOT_ROOT_H
 #define H_UTIL_VSERVER_SRC_COMPAT_PIVOT_ROOT_H
 
-#include <sys/syscall.h>
 #include <unistd.h>
-#include <asm/unistd.h>
 #include <errno.h>
 
+#include "syscall-wrap.h"
+
 inline static _syscall2(int,pivot_root,const char *,new_root,const char *,put_old)
 
 #endif	//  H_UTIL_VSERVER_SRC_COMPAT_PIVOT_ROOT_H
